@@ -113,7 +113,7 @@ class VersionedDataStoreController:
 
         def _execute_distinct_query(self, resource_id, field, offset=0, limit=None):
             col = self._get_resource_collection(resource_id)
-            return {'records': list(col.distinct(key=field))[offset:limit]}
+            return {'records': list(map(lambda x: {field: x}, col.distinct(key=field)))[offset:limit]}
 
         def _get_resource_collection(self, resource_id):
             return self.datastore.get_collection(resource_id)
@@ -296,12 +296,19 @@ class VersionedDataStoreController:
 
                 if include_data:
                     stored_query.update(q.query['filter'])
-                    result['records'] = list(col.find(filter=stored_query,
-                                                      projection=q.query.get('projection'),
-                                                      sort=q.query.get('sort'),
-                                                      skip=offset,
-                                                      limit=limit,
-                                                      hint='_created_valid_to_index'))
+                    if '_created_valid_to_index' in col.index_information().keys():
+                        result['records'] = list(col.find(filter=stored_query,
+                                                          projection=q.query.get('projection'),
+                                                          sort=q.query.get('sort'),
+                                                          skip=offset,
+                                                          limit=limit,
+                                                          hint='_created_valid_to_index'))
+                    else:
+                        result['records'] = list(col.find(filter=stored_query,
+                                                          projection=q.query.get('projection'),
+                                                          sort=q.query.get('sort'),
+                                                          skip=offset,
+                                                          limit=limit))
 
                 result['query'] = q.as_dict()
 
@@ -360,7 +367,7 @@ class VersionedDataStoreController:
             transformed_sort = transform_sort(sort)
 
             if distinct:
-                result = self._execute_distinct_query(resource_id, transformed_projection.keys()[0], offset, limit)
+                result = self._execute_distinct_query(resource_id, list(transformed_projection)[0], offset, limit)
             else:
                 result = self._execute_query(resource_id,
                                              transformed_statement,
