@@ -6,7 +6,7 @@ from ckanext.datastore.backend import DatastoreBackend
 
 from ckanext.mongodatastore.controller.mongodb import VersionedDataStoreController
 
-log = logging.getLogger(__name__)
+logger = logging.getLogger(__name__)
 
 MIN_LIMIT = 1
 MAX_LIMIT = 500
@@ -19,8 +19,8 @@ def raise_exeption(ex):
 def log_parameter_not_used_warning(param_list):
     for param in param_list:
         if param[1]:
-            log.debug('The parameter {0} is set, but has no effect in this DataStore backend implementation!'
-                      .format(param[0]))
+            logger.debug('The parameter {0} is set, but has no effect in this DataStore backend implementation!'
+                         .format(param[0]))
 
 
 class MongoDataStoreBackend(DatastoreBackend):
@@ -55,7 +55,9 @@ class MongoDataStoreBackend(DatastoreBackend):
             indexes = indexes.split(',')
 
         self.mongo_cntr.update_schema(resource_id, fields, indexes, primary_key)
-        self.mongo_cntr.create_resource(resource_id, primary_key)
+
+        if not self.resource_exists(resource_id):
+            self.mongo_cntr.create_resource(resource_id, primary_key)
 
         if records:
             self.mongo_cntr.upsert(resource_id, records)
@@ -166,3 +168,6 @@ class MongoDataStoreBackend(DatastoreBackend):
 
     def drop_function(self, *args, **kwargs):
         raise NotImplementedError()
+
+    def calculate_record_count(self, resource_id):
+        pass
