@@ -1,18 +1,16 @@
 import ckan.plugins as plugins
 import ckan.plugins.toolkit as toolkit
 from ckanext.datastore.interfaces import IDatastoreBackend
-
 from ckanext.mongodatastore import blueprint
-from ckanext.mongodatastore.cli import init_querystore
+from ckanext.mongodatastore.cli import mongodatastore_init_querystore, mongodatastore_check_integrity
 from ckanext.mongodatastore.datastore_backend import MongoDataStoreBackend
-from ckanext.mongodatastore.logic.action import issue_query_pid, querystore_resolve, nonversioned_query
-from ckanext.mongodatastore.util import urlencode
+from ckanext.mongodatastore.logic.action import issue_query_pid, querystore_resolve, nv_query
+from ckanext.mongodatastore.util import encode_handle
 
 
 class MongodatastorePlugin(plugins.SingletonPlugin):
-    plugins.implements(IDatastoreBackend)
+    plugins.implements(IDatastoreBackend, inherit=True)
     plugins.implements(plugins.IConfigurer)
-    plugins.implements(plugins.IRoutes, inherit=True)
     plugins.implements(plugins.IActions)
     plugins.implements(plugins.IBlueprint)
     plugins.implements(plugins.ITemplateHelpers)
@@ -35,7 +33,7 @@ class MongodatastorePlugin(plugins.SingletonPlugin):
         actions = {
             'issue_pid': issue_query_pid,
             'querystore_resolve': querystore_resolve,
-            'nv_query': nonversioned_query
+            'nv_query': nv_query
         }
 
         return actions
@@ -46,8 +44,8 @@ class MongodatastorePlugin(plugins.SingletonPlugin):
 
     # ITemplateHelpers
     def get_helpers(self):
-        return {'urlencode': urlencode}
+        return {'encode_handle': encode_handle}
 
     # IClick
     def get_commands(self):
-        return [init_querystore]
+        return [mongodatastore_init_querystore, mongodatastore_check_integrity]
